@@ -1,7 +1,6 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 #include "puntateform.h"
-#include "socialnetwork.h"
 #include "credits.h"
 #include "optionsform.h"
 
@@ -12,27 +11,26 @@
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow),
       puntateForm(0),
-      socialNetwork(0),
       credits(0),
-      optionsForm(0)
+      optionsForm(0),
+      browser(0)
 {
     ui->setupUi(this);
 
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
     puntateForm = new PuntateForm(this);
-    socialNetwork = new SocialNetwork(this);
     credits = new Credits(this);
     optionsForm = new OptionsForm(this);
-
+    browser = new Browser(this);
 }
 
 MainWindow::~MainWindow()
 {
     if (puntateForm) delete (puntateForm);
-    if (socialNetwork) delete (socialNetwork);
     if (credits) delete (credits);
     if (optionsForm) delete (optionsForm);
+    if (browser) delete (browser);
     delete ui;
 }
 
@@ -106,9 +104,9 @@ void MainWindow::on_cielo_clicked()
 
 void MainWindow::on_ditv_clicked()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/ditv.sh");
-    process.waitForFinished();
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::DiTv);
+    browser->show();
 }
 
 void MainWindow::on_kataweb_clicked()
@@ -127,16 +125,16 @@ void MainWindow::on_rtv_clicked()
 
 void MainWindow::on_telecupole_clicked()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/cupole.sh");
-    process.waitForFinished();
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::Telecupole);
+    browser->show();
 }
 
 void MainWindow::on_actionYoutube_triggered()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/youtube.sh");
-    process.waitForFinished();
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::Youtube);
+    browser->show();
 }
 
 void MainWindow::on_actionOpzioni_triggered()
@@ -146,9 +144,9 @@ void MainWindow::on_actionOpzioni_triggered()
 
 void MainWindow::on_actionServizioPubblico_Online_triggered()
 {
-    QProcess process;
-    process.start("sh /opt/serviziopubblico/script/official.sh");
-    process.waitForFinished();
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::ServizioPubblico);
+    browser->show();
 }
 
 void MainWindow::on_actionRicorda_un_amico_triggered()
@@ -170,12 +168,28 @@ void MainWindow::on_actionPuntate_triggered()
     puntateForm->show();
 }
 
-void MainWindow::on_actionSocial_Network_triggered()
-{
-    socialNetwork->show();
-}
-
 void MainWindow::on_actionCredits_triggered()
 {
     credits->show();
 }
+
+void MainWindow::on_actionFacebook_triggered()
+{
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::Facebook);
+    browser->show();
+}
+
+void MainWindow::on_actionTwitter_triggered()
+{
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::Twitter);
+    browser->show();
+}
+
+void MainWindow::on_actionVauro_triggered()
+{
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::Vauro);
+    browser->show();
+}
